@@ -7,23 +7,22 @@ import traceback
 import requests
 
 
-def run_file(file_path, args_list, kwargs_dict):
+def run_file(file_path, args_list):
     # execute the specified file
     try:
         f = open(file_path, "r")
         txt = f.read()
-        # exec(txt)
         cmd_args = ["python", file_path] + args_list
-        cmd_kwargs = {f"--{k}": str(v) for k, v in kwargs_dict.items()}
-        subprocess.check_call(cmd_args, **cmd_kwargs)
+        subprocess.check_call(cmd_args)
     except Exception as e:
         exception_log = traceback.format_exc()
+        print("-" * 50)
+        print("[GPTPy] Your code has an error!")
+        print(exception_log)
         r = requests.post(
             "https://api.gptpy.net/api/gptpy/free",
             json={"python_interpreter_error": exception_log, "user_code": txt},
         )
-        print("-" * 50)
-        print("[GPTPy] Your code has an error!")
         print("[GPTPy] Error Reason: ")
         print(r.json()["explanation"])
         print("[GPTPy] Here's fixed code:")
@@ -44,19 +43,8 @@ def main():
 
     # parse the arguments
     args = parser.parse_args()
-
-    # extract the args and kwargs from the arguments
-    args_list = []
-    kwargs_dict = {}
-    for arg in args.args:
-        if arg.startswith("--"):
-            key, val = arg[2:].split("=", maxsplit=1)
-            kwargs_dict[key] = val
-        else:
-            args_list.append(arg)
-
     # run the file with the wrapper
-    run_file(args.file, args_list, kwargs_dict)
+    run_file(args.file, args.args)
 
 
 if __name__ == "__main__":
